@@ -86,32 +86,32 @@ info = {
         "דצמ"
     ],
     "monday": [
-        "יום שני",
         "יום ב׳",
+        "יום שני",
         "שני",
         "יום ב"
     ],
     "tuesday": [
-        "יום שלישי",
         "יום ג׳",
+        "יום שלישי",
         "שלישי",
         "יום ג"
     ],
     "wednesday": [
-        "יום רביעי",
         "יום ד׳",
+        "יום רביעי",
         "רביעי",
         "יום ד"
     ],
     "thursday": [
-        "יום חמישי",
         "יום ה׳",
+        "יום חמישי",
         "חמישי",
         "יום ה"
     ],
     "friday": [
-        "יום שישי",
         "יום ו׳",
+        "יום שישי",
         "שישי",
         "יום ו"
     ],
@@ -120,8 +120,8 @@ info = {
         "שבת"
     ],
     "sunday": [
-        "יום ראשון",
         "יום א׳",
+        "יום ראשון",
         "ראשון",
         "יום א"
     ],
@@ -170,130 +170,130 @@ info = {
         "שניות"
     ],
     "relative-type": {
-        "1 year ago": [
-            "השנה שעברה"
-        ],
-        "0 year ago": [
-            "השנה"
-        ],
-        "in 1 year": [
-            "השנה הבאה"
-        ],
-        "1 month ago": [
-            "החודש שעבר"
-        ],
-        "0 month ago": [
-            "החודש"
-        ],
-        "in 1 month": [
-            "החודש הבא"
-        ],
-        "1 week ago": [
-            "השבוע שעבר"
-        ],
-        "0 week ago": [
-            "השבוע"
-        ],
-        "in 1 week": [
-            "השבוע הבא"
-        ],
-        "1 day ago": [
-            "אתמול"
-        ],
         "0 day ago": [
             "היום"
         ],
-        "in 1 day": [
-            "מחר"
-        ],
         "0 hour ago": [
             "בשעה זו"
         ],
         "0 minute ago": [
             "בדקה זו"
         ],
+        "0 month ago": [
+            "החודש"
+        ],
         "0 second ago": [
             "עכשיו"
+        ],
+        "0 week ago": [
+            "השבוע"
+        ],
+        "0 year ago": [
+            "השנה"
+        ],
+        "1 day ago": [
+            "אתמול"
+        ],
+        "1 month ago": [
+            "החודש שעבר"
+        ],
+        "1 week ago": [
+            "השבוע שעבר"
+        ],
+        "1 year ago": [
+            "השנה שעברה"
+        ],
+        "in 1 day": [
+            "מחר"
+        ],
+        "in 1 month": [
+            "החודש הבא"
+        ],
+        "in 1 week": [
+            "השבוע הבא"
+        ],
+        "in 1 year": [
+            "השנה הבאה"
         ]
     },
     "relative-type-regex": {
-        "in \\1 year": [
-            "בעוד (\\d+) שנים"
-        ],
-        "\\1 year ago": [
-            "לפני (\\d+) שנים"
-        ],
-        "in \\1 month": [
-            "בעוד (\\d+) חודשים",
-            "בעוד (\\d+) חו׳"
-        ],
-        "\\1 month ago": [
-            "לפני (\\d+) חודשים",
-            "לפני (\\d+) חו׳"
-        ],
-        "in \\1 week": [
-            "בעוד (\\d+) שבועות",
-            "בעוד (\\d+) שב׳"
-        ],
-        "\\1 week ago": [
-            "לפני (\\d+) שבועות",
-            "לפני (\\d+) שב׳"
-        ],
-        "in \\1 day": [
-            "בעוד יום (\\d+)",
-            "בעוד (\\d+) ימים",
-            "בעוד (\\d+) ימ׳"
-        ],
         "\\1 day ago": [
-            "לפני יום (\\d+)",
-            "לפני (\\d+) ימים",
-            "לפני (\\d+) ימ׳"
-        ],
-        "in \\1 hour": [
-            "בעוד (\\d+) שעות",
-            "בעוד (\\d+) שע׳"
+            "לפני (\\d+[.,]?\\d*) ימים",
+            "לפני (\\d+[.,]?\\d*) ימ׳",
+            "לפני יום (\\d+[.,]?\\d*)"
         ],
         "\\1 hour ago": [
-            "לפני (\\d+) שעות",
-            "לפני (\\d+) שע׳"
-        ],
-        "in \\1 minute": [
-            "בעוד (\\d+) דקות",
-            "בעוד (\\d+) דק׳"
+            "לפני (\\d+[.,]?\\d*) שעות",
+            "לפני (\\d+[.,]?\\d*) שע׳"
         ],
         "\\1 minute ago": [
-            "לפני (\\d+) דקות",
-            "לפני (\\d+) דק׳"
+            "לפני (\\d+[.,]?\\d*) דקות",
+            "לפני (\\d+[.,]?\\d*) דק׳"
         ],
-        "in \\1 second": [
-            "בעוד (\\d+) שניות",
-            "בעוד (\\d+) שנ׳"
+        "\\1 month ago": [
+            "לפני (\\d+[.,]?\\d*) חודשים",
+            "לפני (\\d+[.,]?\\d*) חו׳"
         ],
         "\\1 second ago": [
-            "לפני (\\d+) שניות",
-            "לפני (\\d+) שנ׳"
+            "לפני (\\d+[.,]?\\d*) שניות",
+            "לפני (\\d+[.,]?\\d*) שנ׳"
+        ],
+        "\\1 week ago": [
+            "לפני (\\d+[.,]?\\d*) שבועות",
+            "לפני (\\d+[.,]?\\d*) שב׳"
+        ],
+        "\\1 year ago": [
+            "לפני (\\d+[.,]?\\d*) שנים"
+        ],
+        "in \\1 day": [
+            "בעוד (\\d+[.,]?\\d*) ימים",
+            "בעוד (\\d+[.,]?\\d*) ימ׳",
+            "בעוד יום (\\d+[.,]?\\d*)"
+        ],
+        "in \\1 hour": [
+            "בעוד (\\d+[.,]?\\d*) שעות",
+            "בעוד (\\d+[.,]?\\d*) שע׳"
+        ],
+        "in \\1 minute": [
+            "בעוד (\\d+[.,]?\\d*) דקות",
+            "בעוד (\\d+[.,]?\\d*) דק׳"
+        ],
+        "in \\1 month": [
+            "בעוד (\\d+[.,]?\\d*) חודשים",
+            "בעוד (\\d+[.,]?\\d*) חו׳"
+        ],
+        "in \\1 second": [
+            "בעוד (\\d+[.,]?\\d*) שניות",
+            "בעוד (\\d+[.,]?\\d*) שנ׳"
+        ],
+        "in \\1 week": [
+            "בעוד (\\d+[.,]?\\d*) שבועות",
+            "בעוד (\\d+[.,]?\\d*) שב׳"
+        ],
+        "in \\1 year": [
+            "בעוד (\\d+[.,]?\\d*) שנים"
         ]
     },
     "locale_specific": {},
     "sentence_splitter_group": 1,
     "skip": [
-        "ה-",
         "ב-",
-        "בשעה",
         "בסביבות",
         "בערך",
         "בקירוב",
+        "בשעה",
+        "ה-",
         " ",
-        ".",
-        ",",
-        ";",
-        "-",
-        "/",
         "'",
-        "|",
+        ",",
+        "-",
+        ".",
+        "/",
+        ";",
         "@",
         "[",
         "]",
+        "|",
         "，"
     ],
     "ago": [
