@@ -2,19 +2,19 @@ info = {
     "name": "te",
     "date_order": "DMY",
     "january": [
-        "జనవరి",
-        "జన"
+        "జన",
+        "జనవరి"
     ],
     "february": [
-        "ఫిబ్రవరి",
-        "ఫిబ్ర"
+        "ఫిబ్ర",
+        "ఫిబ్రవరి"
     ],
     "march": [
         "మార్చి"
     ],
     "april": [
-        "ఏప్రిల్",
-        "ఏప్రి"
+        "ఏప్రి",
+        "ఏప్రిల్"
     ],
     "may": [
         "మే"
@@ -26,52 +26,52 @@ info = {
         "జులై"
     ],
     "august": [
-        "ఆగస్టు",
-        "ఆగ"
+        "ఆగ",
+        "ఆగస్టు"
     ],
     "september": [
-        "సెప్టెంబర్",
-        "సెప్టెం"
+        "సెప్టెం",
+        "సెప్టెంబర్"
     ],
     "october": [
-        "అక్టోబర్",
-        "అక్టో"
+        "అక్టో",
+        "అక్టోబర్"
     ],
     "november": [
-        "నవంబర్",
-        "నవం"
+        "నవం",
+        "నవంబర్"
     ],
     "december": [
-        "డిసెంబర్",
-        "డిసెం"
+        "డిసెం",
+        "డిసెంబర్"
     ],
     "monday": [
-        "సోమవారం",
-        "సోమ"
+        "సోమ",
+        "సోమవారం"
     ],
     "tuesday": [
-        "మంగళవారం",
-        "మంగళ"
+        "మంగళ",
+        "మంగళవారం"
     ],
     "wednesday": [
-        "బుధవారం",
-        "బుధ"
+        "బుధ",
+        "బుధవారం"
     ],
     "thursday": [
-        "గురువారం",
-        "గురు"
+        "గురు",
+        "గురువారం"
     ],
     "friday": [
-        "శుక్రవారం",
-        "శుక్ర"
+        "శుక్ర",
+        "శుక్రవారం"
     ],
     "saturday": [
-        "శనివారం",
-        "శని"
+        "శని",
+        "శనివారం"
     ],
     "sunday": [
-        "ఆదివారం",
-        "ఆది"
+        "ఆది",
+        "ఆదివారం"
     ],
     "am": [
         "am"
@@ -80,160 +80,160 @@ info = {
         "pm"
     ],
     "year": [
-        "సంవత్సరం",
-        "సం"
+        "సం",
+        "సంవత్సరం"
     ],
     "month": [
-        "నెల",
-        "నె"
+        "నె",
+        "నెల"
     ],
     "week": [
-        "వారము",
-        "వా"
+        "వా",
+        "వారము"
     ],
     "day": [
-        "దినం",
-        "ది"
+        "ది",
+        "దినం"
     ],
     "hour": [
-        "గంట",
-        "గం"
+        "గం",
+        "గంట"
     ],
     "minute": [
-        "నిమిషము",
+        "ని",
         "నిమి",
-        "ని"
+        "నిమిషము"
     ],
     "second": [
-        "సెకను",
-        "సెక"
+        "సెక",
+        "సెకను"
     ],
     "relative-type": {
-        "1 year ago": [
-            "గత సంవత్సరం"
-        ],
-        "0 year ago": [
-            "ఈ సంవత్సరం"
-        ],
-        "in 1 year": [
-            "తదుపరి సంవత్సరం"
-        ],
-        "1 month ago": [
-            "గత నెల"
-        ],
-        "0 month ago": [
-            "ఈ నెల"
-        ],
-        "in 1 month": [
-            "తదుపరి నెల"
-        ],
-        "1 week ago": [
-            "గత వారం"
-        ],
-        "0 week ago": [
-            "ఈ వారం"
-        ],
-        "in 1 week": [
-            "తదుపరి వారం"
-        ],
-        "1 day ago": [
-            "నిన్న"
-        ],
         "0 day ago": [
             "ఈ రోజు"
         ],
-        "in 1 day": [
-            "రేపు"
-        ],
         "0 hour ago": [
             "ఈ గంట"
         ],
         "0 minute ago": [
             "ఈ నిమిషం"
         ],
+        "0 month ago": [
+            "ఈ నెల"
+        ],
         "0 second ago": [
             "ప్రస్తుతం"
+        ],
+        "0 week ago": [
+            "ఈ వారం"
+        ],
+        "0 year ago": [
+            "ఈ సంవత్సరం"
+        ],
+        "1 day ago": [
+            "నిన్న"
+        ],
+        "1 month ago": [
+            "గత నెల"
+        ],
+        "1 week ago": [
+            "గత వారం"
+        ],
+        "1 year ago": [
+            "గత సంవత్సరం"
+        ],
+        "in 1 day": [
+            "రేపు"
+        ],
+        "in 1 month": [
+            "తదుపరి నెల"
+        ],
+        "in 1 week": [
+            "తదుపరి వారం"
+        ],
+        "in 1 year": [
+            "తదుపరి సంవత్సరం"
         ]
     },
     "relative-type-regex": {
-        "in \\1 year": [
-            "(\\d+) సంవత్సరంలో",
-            "(\\d+) సంవత్సరాల్లో",
-            "(\\d+) సంలో"
-        ],
-        "\\1 year ago": [
-            "(\\d+) సంవత్సరం క్రితం",
-            "(\\d+) సంవత్సరాల క్రితం",
-            "(\\d+) సం క్రితం"
-        ],
-        "in \\1 month": [
-            "(\\d+) నెలలో",
-            "(\\d+) నెలల్లో"
-        ],
-        "\\1 month ago": [
-            "(\\d+) నెల క్రితం",
-            "(\\d+) నెలల క్రితం"
-        ],
-        "in \\1 week": [
-            "(\\d+) వారంలో",
-            "(\\d+) వారాల్లో"
-        ],
-        "\\1 week ago": [
-            "(\\d+) వారం క్రితం",
-            "(\\d+) వారాల క్రితం"
-        ],
-        "in \\1 day": [
-            "(\\d+) రోజులో",
-            "(\\d+) రోజుల్లో"
-        ],
         "\\1 day ago": [
-            "(\\d+) రోజు క్రితం",
-            "(\\d+) రోజుల క్రితం"
-        ],
-        "in \\1 hour": [
-            "(\\d+) గంటలో",
-            "(\\d+) గంటల్లో",
-            "(\\d+) గంలో"
+            "(\\d+[.,]?\\d*) రోజు క్రితం",
+            "(\\d+[.,]?\\d*) రోజుల క్రితం"
         ],
         "\\1 hour ago": [
-            "(\\d+) గంట క్రితం",
-            "(\\d+) గంటల క్రితం",
-            "(\\d+) గం క్రితం"
-        ],
-        "in \\1 minute": [
-            "(\\d+) నిమిషంలో",
-            "(\\d+) నిమిషాల్లో",
-            "(\\d+) నిమిలో"
+            "(\\d+[.,]?\\d*) గం క్రితం",
+            "(\\d+[.,]?\\d*) గంట క్రితం",
+            "(\\d+[.,]?\\d*) గంటల క్రితం"
         ],
         "\\1 minute ago": [
-            "(\\d+) నిమిషం క్రితం",
-            "(\\d+) నిమిషాల క్రితం",
-            "(\\d+) నిమి క్రితం"
+            "(\\d+[.,]?\\d*) నిమి క్రితం",
+            "(\\d+[.,]?\\d*) నిమిషం క్రితం",
+            "(\\d+[.,]?\\d*) నిమిషాల క్రితం"
         ],
-        "in \\1 second": [
-            "(\\d+) సెకనులో",
-            "(\\d+) సెకన్లలో",
-            "(\\d+) సెక లో"
+        "\\1 month ago": [
+            "(\\d+[.,]?\\d*) నెల క్రితం",
+            "(\\d+[.,]?\\d*) నెలల క్రితం"
         ],
         "\\1 second ago": [
-            "(\\d+) సెకను క్రితం",
-            "(\\d+) సెకన్ల క్రితం",
-            "(\\d+) సెక క్రితం"
+            "(\\d+[.,]?\\d*) సెక క్రితం",
+            "(\\d+[.,]?\\d*) సెకను క్రితం",
+            "(\\d+[.,]?\\d*) సెకన్ల క్రితం"
+        ],
+        "\\1 week ago": [
+            "(\\d+[.,]?\\d*) వారం క్రితం",
+            "(\\d+[.,]?\\d*) వారాల క్రితం"
+        ],
+        "\\1 year ago": [
+            "(\\d+[.,]?\\d*) సం క్రితం",
+            "(\\d+[.,]?\\d*) సంవత్సరం క్రితం",
+            "(\\d+[.,]?\\d*) సంవత్సరాల క్రితం"
+        ],
+        "in \\1 day": [
+            "(\\d+[.,]?\\d*) రోజులో",
+            "(\\d+[.,]?\\d*) రోజుల్లో"
+        ],
+        "in \\1 hour": [
+            "(\\d+[.,]?\\d*) గంటలో",
+            "(\\d+[.,]?\\d*) గంటల్లో",
+            "(\\d+[.,]?\\d*) గంలో"
+        ],
+        "in \\1 minute": [
+            "(\\d+[.,]?\\d*) నిమిలో",
+            "(\\d+[.,]?\\d*) నిమిషంలో",
+            "(\\d+[.,]?\\d*) నిమిషాల్లో"
+        ],
+        "in \\1 month": [
+            "(\\d+[.,]?\\d*) నెలలో",
+            "(\\d+[.,]?\\d*) నెలల్లో"
+        ],
+        "in \\1 second": [
+            "(\\d+[.,]?\\d*) సెక లో",
+            "(\\d+[.,]?\\d*) సెకనులో",
+            "(\\d+[.,]?\\d*) సెకన్లలో"
+        ],
+        "in \\1 week": [
+            "(\\d+[.,]?\\d*) వారంలో",
+            "(\\d+[.,]?\\d*) వారాల్లో"
+        ],
+        "in \\1 year": [
+            "(\\d+[.,]?\\d*) సంలో",
+            "(\\d+[.,]?\\d*) సంవత్సరంలో",
+            "(\\d+[.,]?\\d*) సంవత్సరాల్లో"
         ]
     },
     "locale_specific": {},
     "skip": [
         " ",
-        ".",
-        ",",
-        ";",
-        "-",
-        "/",
         "'",
-        "|",
+        ",",
+        "-",
+        ".",
+        "/",
+        ";",
         "@",
         "[",
         "]",
+        "|",
         "，"
     ]
 }
