@@ -150,46 +150,46 @@ info = {
     },
     "relative-type-regex": {
         "\\1 day ago": [
-            "(\\d+) кун олдин"
+            "(\\d+[.,]?\\d*) кун олдин"
         ],
         "\\1 hour ago": [
-            "(\\d+) соат олдин"
+            "(\\d+[.,]?\\d*) соат олдин"
         ],
         "\\1 minute ago": [
-            "(\\d+) дақиқа олдин"
+            "(\\d+[.,]?\\d*) дақиқа олдин"
         ],
         "\\1 month ago": [
-            "(\\d+) ой аввал"
+            "(\\d+[.,]?\\d*) ой аввал"
         ],
         "\\1 second ago": [
-            "(\\d+) сония олдин"
+            "(\\d+[.,]?\\d*) сония олдин"
         ],
         "\\1 week ago": [
-            "(\\d+) ҳафта олдин"
+            "(\\d+[.,]?\\d*) ҳафта олдин"
         ],
         "\\1 year ago": [
-            "(\\d+) йил аввал"
+            "(\\d+[.,]?\\d*) йил аввал"
         ],
         "in \\1 day": [
-            "(\\d+) кундан сўнг"
+            "(\\d+[.,]?\\d*) кундан сўнг"
         ],
         "in \\1 hour": [
-            "(\\d+) соатдан сўнг"
+            "(\\d+[.,]?\\d*) соатдан сўнг"
         ],
         "in \\1 minute": [
-            "(\\d+) дақиқадан сўнг"
+            "(\\d+[.,]?\\d*) дақиқадан сўнг"
         ],
         "in \\1 month": [
-            "(\\d+) ойдан сўнг"
+            "(\\d+[.,]?\\d*) ойдан сўнг"
         ],
         "in \\1 second": [
-            "(\\d+) сониядан сўнг"
+            "(\\d+[.,]?\\d*) сониядан сўнг"
         ],
         "in \\1 week": [
-            "(\\d+) ҳафтадан сўнг"
+            "(\\d+[.,]?\\d*) ҳафтадан сўнг"
         ],
         "in \\1 year": [
-            "(\\d+) йилдан сўнг"
+            "(\\d+[.,]?\\d*) йилдан сўнг"
         ]
     },
     "locale_specific": {},
