@@ -2,24 +2,25 @@ import calendar
 import logging
 import types
 import unicodedata
+from collections import OrderedDict
 from datetime import datetime
 
 import regex as re
+from pytz import UTC, UnknownTimeZoneError, timezone
 from tzlocal import get_localzone
-from pytz import UTC, timezone, UnknownTimeZoneError
-from collections import OrderedDict
 
-from dateparser.timezone_parser import _tz_offsets, StaticTzInfo
+from dateparser.timezone_parser import StaticTzInfo, _tz_offsets
 
 
 def strip_braces(date_string):
-    return re.sub(r'[{}()<>\[\]]+', '', date_string)
+    return re.sub(r"[{}()<>\[\]]+", "", date_string)
 
 
-def normalize_unicode(string, form='NFKD'):
-    return ''.join(
-        c for c in unicodedata.normalize(form, string)
-        if unicodedata.category(c) != 'Mn'
+def normalize_unicode(string, form="NFKD"):
+    return "".join(
+        c
+        for c in unicodedata.normalize(form, string)
+        if unicodedata.category(c) != "Mn"
     )
 
 
@@ -35,14 +36,16 @@ def combine_dicts(primary_dict, supplementary_dict):
                 combined_dict[key] = supplementary_dict[key]
         else:
             combined_dict[key] = primary_dict[key]
-    remaining_keys = [key for key in supplementary_dict.keys() if key not in primary_dict.keys()]
+    remaining_keys = [
+        key for key in supplementary_dict.keys() if key not in primary_dict.keys()
+    ]
     for key in remaining_keys:
         combined_dict[key] = supplementary_dict[key]
     return combined_dict
 
 
 def find_date_separator(format):
-    m = re.search(r'(?:(?:%[dbBmaA])(\W))+', format)
+    m = re.search(r"(?:(?:%[dbBmaA])(\W))+", format)
     if m:
         return m.group(1)
 
@@ -53,13 +56,14 @@ def _get_missing_parts(fmt):
     from a date format checking its directives
     """
     directive_mapping = {
-        'day': ['%d', '%-d', '%j', '%-j'],
-        'month': ['%b', '%B', '%m', '%-m'],
-        'year': ['%y', '%-y', '%Y']
+        "day": ["%d", "%-d", "%j", "%-j"],
+        "month": ["%b", "%B", "%m", "%-m"],
+        "year": ["%y", "%-y", "%Y"],
     }
 
     missing = [
-        field for field in ('day', 'month', 'year')
+        field
+        for field in ("day", "month", "year")
         if not any(directive in fmt for directive in directive_mapping[field])
     ]
     return missing
@@ -70,8 +74,8 @@ def get_timezone_from_tz_string(tz_string):
         return timezone(tz_string)
     except UnknownTimeZoneError as e:
         for name, info in _tz_offsets:
-            if info['regex'].search(' %s' % tz_string):
-                return StaticTzInfo(name, info['offset'])
+            if info["regex"].search(" %s" % tz_string):
+                return StaticTzInfo(name, info["offset"])
         else:
             raise e
 
@@ -82,7 +86,7 @@ def localize_timezone(date_time, tz_string):
 
     tz = get_timezone_from_tz_string(tz_string)
 
-    if hasattr(tz, 'localize'):
+    if hasattr(tz, "localize"):
         date_time = tz.localize(date_time)
     else:
         date_time = date_time.replace(tzinfo=tz)
@@ -101,14 +105,14 @@ def apply_tzdatabase_timezone(date_time, pytz_string):
 
 def apply_dateparser_timezone(utc_datetime, offset_or_timezone_abb):
     for name, info in _tz_offsets:
-        if info['regex'].search(' %s' % offset_or_timezone_abb):
-            tz = StaticTzInfo(name, info['offset'])
+        if info["regex"].search(" %s" % offset_or_timezone_abb):
+            tz = StaticTzInfo(name, info["offset"])
             return utc_datetime.astimezone(tz)
 
 
 def apply_timezone(date_time, tz_string):
     if not date_time.tzinfo:
-        if hasattr(UTC, 'localize'):
+        if hasattr(UTC, "localize"):
             date_time = UTC.localize(date_time)
         else:
             date_time = date_time.replace(tzinfo=UTC)
@@ -126,8 +130,8 @@ def apply_timezone_from_settings(date_obj, settings):
     if settings is None:
         return date_obj
 
-    if 'local' in settings.TIMEZONE.lower():
-        if hasattr(tz, 'localize'):
+    if "local" in settings.TIMEZONE.lower():
+        if hasattr(tz, "localize"):
             date_obj = tz.localize(date_obj)
         else:
             date_obj = date_obj.replace(tzinfo=tz)
@@ -168,17 +172,27 @@ def _get_leap_year(year, future):
 
 
 def set_correct_day_from_settings(date_obj, settings, current_day=None):
-    """ Set correct day attending the `PREFER_DAY_OF_MONTH` setting."""
+    """Set correct day attending the `PREFER_DAY_OF_MONTH` setting."""
     options = {
-        'first': 1,
-        'last': get_last_day_of_month(date_obj.year, date_obj.month),
-        'current': current_day or datetime.now().day
+        "first": 1,
+        "last": get_last_day_of_month(date_obj.year, date_obj.month),
+        "current": current_day or datetime.now().day,
     }
 
     try:
         return date_obj.replace(day=options[settings.PREFER_DAY_OF_MONTH])
     except ValueError:
-        return date_obj.replace(day=options['last'])
+        return date_obj.replace(day=options["last"])
+
+
+def set_correct_month_from_settings(date_obj, settings, current_month=None):
+    """Set correct month attending the `PREFER_MONTH_OF_YEAR` setting."""
+    options = {"first": 1, "last": 12, "current": current_month or datetime.now().month}
+
+    try:
+        return date_obj.replace(month=options[settings.PREFER_MONTH_OF_YEAR])
+    except ValueError:
+        return date_obj.replace(month=options["last"])
 
 
 def registry(cls):
@@ -192,22 +206,27 @@ def registry(cls):
 
             if key not in registry_dict:
                 registry_dict[key] = creator(cls, *args)
-                setattr(registry_dict[key], 'registry_key', key)
+                setattr(registry_dict[key], "registry_key", key)
             return registry_dict[key]
+
         return staticmethod(constructor)
 
-    if not (hasattr(cls, "get_key")
-            and isinstance(cls.get_key, types.MethodType)
-            and cls.get_key.__self__ is cls):
-        raise NotImplementedError("Registry classes require to implement class method get_key")
+    if not (
+        hasattr(cls, "get_key")
+        and isinstance(cls.get_key, types.MethodType)
+        and cls.get_key.__self__ is cls
+    ):
+        raise NotImplementedError(
+            "Registry classes require to implement class method get_key"
+        )
 
-    setattr(cls, '__new__', choose(cls.__new__))
+    setattr(cls, "__new__", choose(cls.__new__))
     return cls
 
 
 def get_logger():
     setup_logging()
-    return logging.getLogger('dateparser')
+    return logging.getLogger("dateparser")
 
 
 def setup_logging():
@@ -215,24 +234,24 @@ def setup_logging():
         return
 
     config = {
-        'version': 1,
-        'disable_existing_loggers': True,
-        'formatters': {
-            'console': {
-                'format': "%(asctime)s %(levelname)s: [%(name)s] %(message)s",
+        "version": 1,
+        "disable_existing_loggers": True,
+        "formatters": {
+            "console": {
+                "format": "%(asctime)s %(levelname)s: [%(name)s] %(message)s",
             },
         },
-        'handlers': {
-            'console': {
-                'level': logging.DEBUG,
-                'class': "logging.StreamHandler",
-                'formatter': "console",
-                'stream': "ext://sys.stdout",
+        "handlers": {
+            "console": {
+                "level": logging.DEBUG,
+                "class": "logging.StreamHandler",
+                "formatter": "console",
+                "stream": "ext://sys.stdout",
             },
         },
-        'root': {
-            'level': logging.DEBUG,
-            'handlers': ["console"],
+        "root": {
+            "level": logging.DEBUG,
+            "handlers": ["console"],
         },
     }
     logging.config.dictConfig(config)
