@@ -10,9 +10,8 @@
 # file.
 
 
-import sys
 import os
-
+import sys
 
 # Get the project root dir, which is the parent dir of this
 cwd = os.getcwd()
@@ -29,20 +28,25 @@ import dateparser
 
 # Add any Sphinx extension module names here, as strings. They can be
 # extensions coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
-extensions = ['sphinx.ext.autodoc', 'sphinx.ext.viewcode', 'sphinx.ext.intersphinx', 'sphinx_rtd_theme']
+extensions = [
+    "sphinx.ext.autodoc",
+    "sphinx.ext.viewcode",
+    "sphinx.ext.intersphinx",
+    "sphinx_rtd_theme",
+]
 
 # Add any paths that contain templates here, relative to this directory.
-templates_path = ['_templates']
+templates_path = ["_templates"]
 
 # The suffix of source filenames.
-source_suffix = '.rst'
+source_suffix = ".rst"
 
 # The master toctree document.
-master_doc = 'index'
+master_doc = "index"
 
 # General information about the project.
-project = 'DateParser'
-copyright = '2014, Scrapinghub'
+project = "DateParser"
+copyright = "2014, Scrapinghub"
 
 # The version info for the project you're documenting, acts as replacement
 # for |version| and |release|, also used in various other places throughout
@@ -55,17 +59,17 @@ release = dateparser.__version__
 
 # List of patterns, relative to source directory, that match files and
 # directories to ignore when looking for source files.
-exclude_patterns = ['_build']
+exclude_patterns = ["_build"]
 
 # The name of the Pygments (syntax highlighting) style to use.
-pygments_style = 'sphinx'
+pygments_style = "sphinx"
 
 
 # -- Options for HTML output -------------------------------------------
 
 # The theme to use for HTML and HTML Help pages.  See the documentation for
 # a list of builtin themes.
-html_theme = 'sphinx_rtd_theme'
+html_theme = "sphinx_rtd_theme"
 
 # Add any paths that contain custom static files (such as style sheets)
 # here, relative to this directory. They are copied after the builtin
@@ -74,7 +78,7 @@ html_theme = 'sphinx_rtd_theme'
 html_static_path = []
 
 # Output file base name for HTML help builder.
-htmlhelp_basename = 'dateparserdoc'
+htmlhelp_basename = "dateparserdoc"
 
 
 # -- Options for LaTeX output ------------------------------------------
@@ -85,9 +89,7 @@ latex_elements = {}
 # (source start file, target name, title, author, documentclass
 # [howto/manual]).
 latex_documents = [
-    ('index', 'dateparser.tex',
-     'DateParser Documentation',
-     'Scrapinghub', 'manual'),
+    ("index", "dateparser.tex", "DateParser Documentation", "Scrapinghub", "manual"),
 ]
 
 
@@ -95,11 +97,7 @@ latex_documents = [
 
 # One entry per manual page. List of tuples
 # (source start file, name, description, authors, manual section).
-man_pages = [
-    ('index', 'dateparser',
-     'DateParser Documentation',
-     ['Scrapinghub'], 1)
-]
+man_pages = [("index", "dateparser", "DateParser Documentation", ["Scrapinghub"], 1)]
 
 
 # -- Options for Texinfo output ----------------------------------------
@@ -108,25 +106,28 @@ man_pages = [
 # (source start file, target name, title, author,
 #  dir menu entry, description, category)
 texinfo_documents = [
-    ('index', 'dateparser',
-     'DateParser Documentation',
-     'Scrapinghub',
-     'dateparser',
-     'One line description of project.',
-     'Miscellaneous'),
+    (
+        "index",
+        "dateparser",
+        "DateParser Documentation",
+        "Scrapinghub",
+        "dateparser",
+        "One line description of project.",
+        "Miscellaneous",
+    ),
 ]
 
 # sphinx.ext.intersphinx confs
-intersphinx_mapping = {'python': ('https://docs.python.org/3', None)}
+intersphinx_mapping = {"python": ("https://docs.python.org/3", None)}
 
 
 html_theme_options = {
-    'logo_only': True,
-    'collapse_navigation': True,
-    'sticky_navigation': True,
-    'navigation_depth': 4,
-    'includehidden': True,
-    'titles_only': False
+    "logo_only": True,
+    "collapse_navigation": True,
+    "sticky_navigation": True,
+    "navigation_depth": 4,
+    "includehidden": True,
+    "titles_only": False,
 }
 
 html_logo = "../artwork/dateparser-logo.png"
