@@ -19,6 +19,8 @@ class BaseTestCase(TestCase):
 
     def then_error_was_raised(self, error_cls, allowed_substrings=()):
         self.assertIsInstance(self.error, error_cls)
-        self.assertTrue(any(mesg in str(self.error) for mesg in allowed_substrings),
-                        "Didn't found any of the expected messages (%r) -- message was: %r" % (
-                            allowed_substrings, self.error))
+        self.assertTrue(
+            any(mesg in str(self.error) for mesg in allowed_substrings),
+            "Didn't found any of the expected messages (%r) -- message was: %r"
+            % (allowed_substrings, self.error),
+        )
